#!/usr/bin/env python -3
# -*- coding: utf-8 -*-
#
# Copyright 2010 K. Richard Pixley.
# See LICENSE for details.
#
# Time-stamp: <23-Feb-2010 17:45:46 PST by rich@noir.com>

"""
Test cases for metaserializer.
"""

__docformat__ = 'epytext'

from StringIO import StringIO

import unittest
import nose

from metaserializer import MetaSerializer
from metaserializer.mspickle import PickleDefault, PickleHighest
from metaserializer.msyaml import YAML
#from metaserializer.msjson import JSON

class Base(unittest.TestCase):
    def setUp(self):
        self.serializer = MetaSerializer()
        self.assertTrue(isinstance(self.serializer.name, str))
        self.stringfile = StringIO()

    def tearDown(self):
        pass


class TestBasics(Base):
    def test_dump(self):
        self.assertRaises(NotImplementedError, self.serializer.dump, 'test', self.stringfile)

    def test_load(self):
        self.assertRaises(NotImplementedError, self.serializer.load, self.stringfile)

    def test_dumps(self):
        self.assertRaises(NotImplementedError, self.serializer.dumps, 'test')

    def test_loads(self):
        self.assertRaises(NotImplementedError, self.serializer.loads, 'test')

def test_generator():
    samples = [None, True, False, '', (), [], {}, 'test1, 2', (1, 2, 3), [4, 5, 6], {7: 8, 9: 10, 11: 12}]

    #string_only = [JSON()]
    string_only = []
    file_only = []
    both = [PickleDefault(), PickleHighest(), YAML()]

    for serializer in string_only + both:
        for exp in [samples] + samples:
            yield (stringLoopback, serializer, exp)

    for serializer in file_only + both:
        for exp in [samples] + samples:
            yield (fileLoopback, serializer, exp)

def stringLoopback(serializer, obj):
    s = serializer.dumps(obj)
    nose.tools.assert_true(isinstance(s, str))
    o = serializer.loads(s)
    nose.tools.assert_equals(o, obj)

def fileLoopback(serializer, obj):
    stringfile = StringIO()

    serializer.dump(obj, stringfile)
    stringfile.seek(0)
    o = serializer.load(stringfile)
    nose.tools.assert_equals(o, obj)


if __name__ == '__main__':
    nose.main()
    print 'done'



#!/usr/bin/env python -3
# -*- coding: utf-8 -*-
#
# Copyright 2010 K. Richard Pixley.
# See LICENSE for details.
#
# Time-stamp: <23-Feb-2010 13:29:05 PST by rich@noir.com>

"""
A package which offers a simple, covering interface for a variety of other serializers.
"""

__docformat__ = 'epytext'

__all__ = []


# FIXME: does this need an 'implements?' predicate?

class MetaSerializer(object):
    """
    Base class for MetaSerializer objects.

    @ivar name:
    @type name: C{str}
    """

    name = 'unknown'

    def dump(self, o, f):
        """
        Serialize an C{object} into a C{file}.

        @param object:
        @type object: C{object}

        @param file:
        @type file: C{file}
        """
        raise NotImplementedError

    def load(self, f):
        """
        Unserialize an C{object} from a C{file}.

        @param file:
        @type file: C{file}

        @return:
        @rtype: C{object}
        """
        raise NotImplementedError

    def dumps(self, o):
        """
        Serialize an C{object} into a C{str}.

        @param object:
        @type object: C{object}

        @return:
        @rtype: C{str}
        """
        raise NotImplementedError

    def loads(self, s):
        """
        Unserialize an C{object} from a C{str}.

        @param string:
        @type string: C{str}

        @return:
        @rtype: C{object}
        """
        raise NotImplementedError



#!/usr/bin/env python -3
# -*- coding: utf-8 -*-
#
# Copyright 2010 K. Richard Pixley.
# See LICENSE for details.
#
# Time-stamp: <23-Feb-2010 17:46:17 PST by rich@noir.com>

"""
This module subclasses the MetaSerializer object into a json
serializer based on the standard libary json module, (aka,
simplejson).

@note: this serializer doesn't actually consume what it produces as a
noop.
"""

__docformat__ = 'epytext'

from metaserializer import MetaSerializer

import json

class JSON(MetaSerializer):
    """
    This serializer is based on the standard library json module, (aka, simplejson).
    """
    name = 'json'

    def dumps(self, object):
        return json.dumps(object, sort_keys=True, indent=4)

    def loads(self, string):
        return json.loads(string)



#!/usr/bin/env python -3
# -*- coding: utf-8 -*-
#
# Copyright 2010 K. Richard Pixley.
# See LICENSE for details.
#
# Time-stamp: <23-Feb-2010 17:37:00 PST by rich@noir.com>

"""
This module subclasses the MetaSerializer object into a yaml
serializer based on PyYAML.
"""

__docformat__ = 'epytext'

from metaserializer import MetaSerializer

import yaml
try:
    from yaml import CLoader as Loader
    from yaml import CDumper as Dumper
except ImportError:
    from yaml import Loader, Dumper

class YAML(MetaSerializer):
    """
    This serializer is based on U{PyYAML<http://pypi.python.org/pypi/PyYAML>}.
    """
    name = 'yaml'

    def dump(self, object, file):
        yaml.dump(object, file, Dumper=Dumper)

    def load(self, file):
        return yaml.load(file, Loader=Loader)

    def dumps(self, object):
        return yaml.dump(object, Dumper=Dumper)

    def loads(self, string):
        return yaml.load(string, Loader=Loader)



#!/usr/bin/env python -3
# -*- coding: utf-8 -*-
#
# Copyright 2010 K. Richard Pixley.
# See LICENSE for details.
#
# Time-stamp: <23-Feb-2010 17:18:50 PST by rich@noir.com>

"""
This module subclasses the MetaSerializer object into two distinct
subclasses both of which are based on the pickle module from the
standard library.
"""

__docformat__ = 'epytext'

from metaserializer import MetaSerializer

try:
    import cPickle as pickle
except ImportError:
    import pickle

class PickleDefault(MetaSerializer):
    """
    This serializer is based on the standard library L{pickle} module
    used with it's default protocol.
    """

    name = 'pickledefault'
    _protocol = 0

    def dump(self, object, file):
        pickle.dump(object, file, self._protocol)

    def load(self, file):
        return pickle.load(file)

    def dumps(self, object):
        return pickle.dumps(object, self._protocol)

    def loads(self, string):
        return pickle.loads(string)


class PickleHighest(PickleDefault):
    """
    This serializer is based on the standard libary L{pickle} modules
    used with it's highest available protocol.
    """
    name = 'picklehighest'
    _protocol = pickle.HIGHEST_PROTOCOL



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2010 K. Richard Pixley.
# See LICENSE for details.
#
# Time-stamp: <24-Feb-2010 03:39:23 PST by rich@noir.com>

import os

try:
    from setuptools import setup, find_packages
except ImportError:
    from ez_setup import use_setuptools
    use_setuptools()
    from setuptools import setup, find_packages

def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

setup(
    name='metaserializer',
    version='0.004',
    author='K. Richard Pixley',
    author_email='rich@noir.com',
    description='A cover library for various other serializers.',
    license='MIT',
    keywords='serializer yaml pickle',
    url='http://packages.python.org/metaserializer',
    long_description=read('README'),
    setup_requires=[
    	'nose>=0.11.1',
    ],
    install_requires=[
    	"PyYAML>=3.09",
    ],
    packages=find_packages(),
    include_package_data=True,
    test_suite='nose.collector',
    py_modules=['metaserializer'],
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2.6',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Utilities',
    ],
)
